pub enum ParseError {
CommonMetadataNotAligned(u32),
HashTableNotAligned(u32),
InputUnexpectedTermination,
InvalidFormat(ElfError),
InvalidValue,
IO(IOError),
MetadataNotAligned(u32),
NoHashTableSegment,
UnsupportedHeaderVersion(u32),
}Expand description
The error type for parsing MBN format file.
Variants
CommonMetadataNotAligned(u32)
Length of common metadata is not 24 bytes.
HashTableNotAligned(u32)
Length of hash table is not a multiple of 32 or 48, or hash table does not contain at least 2 entries.
InputUnexpectedTermination
Input buffer length may be not long enough.
InvalidFormat(ElfError)
File or byte stream format is invalid.
InvalidValue
Input value is invalid.
IO(IOError)
I/O Error.
MetadataNotAligned(u32)
Length of metadata is not 120 or 224 bytes.
NoHashTableSegment
Cannot find hash table segment.
UnsupportedHeaderVersion(u32)
MBN header version is not supported.